@@ -31,11 +31,13 @@
 one2one_line <- function(data,
                          hrvar = "Organization",
                          mingroup = 5,
-                         return = "plot"){
+                         return = "plot",
+                         label = FALSE){
   ## Inherit arguments
   create_line(data = data,
               metric = "Meeting_and_call_hours_with_manager_1_1",
               hrvar = hrvar,
               mingroup = mingroup,
-              return = return)
+              return = return,
+              label = label)
 }
